==> haskell-vector-space-0.16-144-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-space.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-space
version:              0.16
visibility:           public
id:                   vector-space-0.16-F9ObmowUh9IJ2XjRnGde80
key:                  vector-space-0.16-F9ObmowUh9IJ2XjRnGde80
license:              BSD-3-Clause
copyright:            (c) 2008-2012 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott 
stability:            experimental
synopsis:             Vector & affine spaces, linear maps, and derivatives
description:
    /vector-space/ provides classes and generic operations for vector
    spaces and affine spaces.  It also defines a type of infinite towers
    of generalized derivatives.  A generalized derivative is a linear
    transformation rather than one of the common concrete representations
    (scalars, vectors, matrices, ...).

    /Warning/: this package depends on type families working fairly well,
    requiring GHC version at least 6.9.

    Project wiki page: <http://haskell.org/haskellwiki/vector-space>

    &#169; 2008-2012 by Conal Elliott; BSD3 license.

category:             math
abi:                  eb97d43705130c09aae9e23086469683
exposed:              True
exposed-modules:
    Data.AdditiveGroup Data.AffineSpace Data.Basis Data.Cross
    Data.Derivative Data.LinearMap Data.Maclaurin Data.VectorSpace

hidden-modules:       Data.VectorSpace.Generic
import-dirs:          /usr/lib/ghc-9.4.8/site-local/vector-space-0.16
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vector-space-0.16
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vector-space-0.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-space
hs-libraries:         HSvector-space-0.16-F9ObmowUh9IJ2XjRnGde80
depends:
    Boolean-0.2.4-LIaGyLXCKND29bUBbSsJWj
    MemoTrie-0.6.11-2FivWXzu1Qe4XIyz5xz0Nj
    NumInstances-1.4-4OncN3WniO73xybRJJuGAa base-4.17.2.1

haddock-interfaces:
    /usr/share/doc/haskell-vector-space/html/vector-space.haddock

haddock-html:         /usr/share/doc/haskell-vector-space/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-space-0.16-149-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-space.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-space
version:              0.16
visibility:           public
id:                   vector-space-0.16-12MKCSuuYJlFnDhIPRnF5Y
key:                  vector-space-0.16-12MKCSuuYJlFnDhIPRnF5Y
license:              BSD-3-Clause
copyright:            (c) 2008-2012 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott 
stability:            experimental
synopsis:             Vector & affine spaces, linear maps, and derivatives
description:
    /vector-space/ provides classes and generic operations for vector
    spaces and affine spaces.  It also defines a type of infinite towers
    of generalized derivatives.  A generalized derivative is a linear
    transformation rather than one of the common concrete representations
    (scalars, vectors, matrices, ...).

    /Warning/: this package depends on type families working fairly well,
    requiring GHC version at least 6.9.

    Project wiki page: <http://haskell.org/haskellwiki/vector-space>

    &#169; 2008-2012 by Conal Elliott; BSD3 license.

category:             math
abi:                  5144e02eed3e623d1624d670d8ed73df
exposed:              True
exposed-modules:
    Data.AdditiveGroup Data.AffineSpace Data.Basis Data.Cross
    Data.Derivative Data.LinearMap Data.Maclaurin Data.VectorSpace

hidden-modules:       Data.VectorSpace.Generic
import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/vector-space-0.16
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/vector-space-0.16
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/vector-space-0.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-space
hs-libraries:         HSvector-space-0.16-12MKCSuuYJlFnDhIPRnF5Y
depends:
    Boolean-0.2.4-IBCylxYhqeiCCEJgzBhoOY
    MemoTrie-0.6.11-HKYG1gjsvdoKLKhOXA0cAl
    NumInstances-1.4-4TG7AaeYvUV8TiozI3l2Qr base-4.18.3.0

haddock-interfaces:
    /usr/share/doc/haskell-vector-space/html/vector-space.haddock

haddock-html:         /usr/share/doc/haskell-vector-space/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
